@@ -12,7 +12,7 @@ our @EXPORT = qw(
 	&assert
 );
 use vars qw/$VERSION/;
-$VERSION = '1.22';
+$VERSION = '1.23';
 
 use Carp qw/croak carp/;
 
@@ -76,8 +76,14 @@ package is a no-op.
 
 =head1 AUTHOR
 
-Steffen Mueller E<lt>assert-module at steffen-mueller dot netE<gt>
+Steffen Mueller E<lt>smueller@cpan.orgE<gt>
 
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2003-2009 Steffen Mueller
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 =head1 SEE ALSO
 
 L<Sub::Assert>
